@@ -1,5 +1,34 @@
 #!/usr/bin/env python
-# $Id: test_contrib.py 800 2010-12-20 20:08:49Z g.rodola $
+# $Id: test_contrib.py 977 2012-01-22 23:05:09Z g.rodola $
+
+#  pyftpdlib is released under the MIT license, reproduced below:
+#  ======================================================================
+#  Copyright (C) 2007-2012 Giampaolo Rodola' <g.rodola@gmail.com>
+#
+#                         All Rights Reserved
+#
+# Permission is hereby granted, free of charge, to any person
+# obtaining a copy of this software and associated documentation
+# files (the "Software"), to deal in the Software without
+# restriction, including without limitation the rights to use,
+# copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the
+# Software is furnished to do so, subject to the following
+# conditions:
+#
+# The above copyright notice and this permission notice shall be
+# included in all copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
+# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
+# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+# OTHER DEALINGS IN THE SOFTWARE.
+#
+#  ======================================================================
 
 """Tests for pyftpdlib.contrib namespace: handlers.py, authorizers.py
 and filesystems.py modules.
@@ -82,10 +111,6 @@ class TestFtpListingCmdsTLSMixin(TLSTestMixin, TestFtpListingCmds): pass
 class TestFtpAbortTLSMixin(TLSTestMixin, TestFtpAbort):
     def test_oob_abor(self): pass
 
-class TestThrottleBandwidthTLSMixin(TLSTestMixin, ThrottleBandwidth):
-    def test_throttle_recv(self): pass
-    def test_throttle_send(self): pass
-
 class TestTimeoutsTLSMixin(TLSTestMixin, TestTimeouts):
     def test_data_timeout_not_reached(self): pass
 
@@ -96,6 +121,7 @@ class TestCallbacksTLSMixin(TLSTestMixin, TestCallbacks):
     def test_on_incomplete_file_received(self): pass
     def test_on_incomplete_file_sent(self): pass
     def test_on_login(self): pass
+    def test_on_login_failed(self): pass
     def test_on_logout_quit(self): pass
     def test_on_logout_rein(self): pass
     def test_on_logout_user_issued_twice(self): pass
@@ -199,7 +225,12 @@ class TestFTPS(unittest.TestCase):
                 return
             raise
         sock.sendall('noop')
-        self.assertRaises(socket.error, sock.recv, 1024)
+        try:
+            chunk = sock.recv(1024)
+        except socket.error:
+            pass
+        else:
+            self.assertEqual(chunk, "")
 
     def test_tls_control_required(self):
         self.server.handler.tls_control_required = True
@@ -232,10 +263,11 @@ class TestFTPS(unittest.TestCase):
             self.client.quit()
 
     def test_ssl_version(self):
-        protos = (ssl.PROTOCOL_SSLv2, ssl.PROTOCOL_SSLv3,
-                  ssl.PROTOCOL_SSLv23, ssl.PROTOCOL_TLSv1)
-        for proto in protos:
-            self.try_protocol_combo(ssl.PROTOCOL_SSLv2, proto)
+        protos = [ssl.PROTOCOL_SSLv3, ssl.PROTOCOL_SSLv23, ssl.PROTOCOL_TLSv1]
+        if hasattr(ssl, "PROTOCOL_SSLv2"):
+            protos.append(ssl.PROTOCOL_SSLv2)
+            for proto in protos:
+                self.try_protocol_combo(ssl.PROTOCOL_SSLv2, proto)
         for proto in protos:
             self.try_protocol_combo(ssl.PROTOCOL_SSLv3, proto)
         for proto in protos:
@@ -243,12 +275,13 @@ class TestFTPS(unittest.TestCase):
         for proto in protos:
             self.try_protocol_combo(ssl.PROTOCOL_TLSv1, proto)
 
-    def test_sslv2(self):
-        self.client.ssl_version = ssl.PROTOCOL_SSLv2
-        self.client.close()
-        self.client.connect(self.server.host, self.server.port)
-        self.assertRaises(socket.error, self.client.login)
-        self.client.ssl_version = ssl.PROTOCOL_SSLv2
+    if hasattr(ssl, "PROTOCOL_SSLv2"):
+        def test_sslv2(self):
+            self.client.ssl_version = ssl.PROTOCOL_SSLv2
+            self.client.close()
+            self.client.connect(self.server.host, self.server.port)
+            self.assertRaises(socket.error, self.client.login)
+            self.client.ssl_version = ssl.PROTOCOL_SSLv2
 
 
 # --- System dependant authorizers tests
@@ -410,7 +443,6 @@ class SharedAuthorizerTests(unittest.TestCase):
     def test_override_user_perm(self):
         auth = self.authorizer_class()
         user = self.get_current_user()
-        dir = os.path.dirname(os.getcwd())
         auth.override_user(user, perm="elr")
         self.assertEqual(auth.get_perms(user), "elr")
         # make sure other settings keep using default values
@@ -422,7 +454,6 @@ class SharedAuthorizerTests(unittest.TestCase):
     def test_override_user_msg_login_quit(self):
         auth = self.authorizer_class()
         user = self.get_current_user()
-        dir = os.path.dirname(os.getcwd())
         auth.override_user(user, msg_login="foo", msg_quit="bar")
         self.assertEqual(auth.get_msg_login(user), "foo")
         self.assertEqual(auth.get_msg_quit(user), "bar")
@@ -499,6 +530,15 @@ class TestUnixAuthorizer(SharedAuthorizerTests):
         warnings.resetwarnings()
         self.assertTrue(auth.has_perm('anonymous', 'w'))
 
+    def test_validate_authentication(self):
+        # we can only test for invalid credentials
+        auth = authorizers.UnixAuthorizer(require_valid_shell=False)
+        ret = auth.validate_authentication('?!foo', '?!foo')
+        self.assertFalse(ret)
+        auth = authorizers.UnixAuthorizer(require_valid_shell=True)
+        ret = auth.validate_authentication('?!foo', '?!foo')
+        self.assertFalse(ret)
+
     def test_validate_authentication_anonymous(self):
         current_user = self.get_current_user()
         auth = authorizers.UnixAuthorizer(anonymous_user=current_user,
@@ -586,7 +626,6 @@ def test_main():
                       TestFtpRetrieveDataTLSMixin,
                       TestFtpListingCmdsTLSMixin,
                       TestFtpAbortTLSMixin,
-                      TestThrottleBandwidthTLSMixin,
                       TestTimeoutsTLSMixin,
                       TestConfigurableOptionsTLSMixin,
                       TestCallbacksTLSMixin,
@@ -616,7 +655,6 @@ def test_main():
                 warns.append("UnixAuthorizer tests skipped (root privileges are "
                              "required)")
             else:
-                warn_skip = False
                 tests.append(TestUnixAuthorizer)
         else:
             try:
@@ -655,4 +693,3 @@ def test_main():
 
 if __name__ == '__main__':
     test_main()
-
